@@ -1,13 +1,14 @@
 """
 Admin API requests.
 """
-from typing import List, Dict
+from typing import List, Dict, Optional
 
 from algora.api.service.admin.__util import (
     _get_client_id_request_info, _get_users_request_info, _get_user_request_info, _update_user_request_info,
     _get_groups_request_info, _get_group_members_request_info, _add_group_to_user_request_info,
     _delete_group_from_user_request_info, _get_roles_request_info, _get_roles_for_user_request_info,
-    _add_role_mapping_to_user_request_info, _execute_actions_email_request_info
+    _add_role_mapping_to_user_request_info, _execute_actions_email_request_info, _create_offline_token_request_info,
+    _update_offline_token_request_info, _get_offline_token_request_info, _delete_offline_token_request_info
 )
 from algora.common.decorators import data_request
 from algora.common.function import no_transform
@@ -29,14 +30,14 @@ def get_client_id():
 
 
 @data_request
-def get_users():
+def get_users(limit: int = 500):
     """
     Get all users.
 
     Returns:
         List of user response.
     """
-    request_info = _get_users_request_info()
+    request_info = _get_users_request_info(limit)
     return __get_request(**request_info)
 
 
@@ -189,3 +190,67 @@ def add_role_mapping_to_user(user_id: str, role_ids: List[Dict[str, str]]):
     """
     request_info = _add_role_mapping_to_user_request_info(user_id, role_ids)
     return __post_request(**request_info)
+
+
+@data_request(transformer=no_transform)
+def get_offline_token(user_id: str) -> dict:
+    """
+    Get offline token for user.
+
+    Args:
+        user_id (str): User ID
+
+    Returns:
+        dict: Offline token response
+    """
+    request_info = _get_offline_token_request_info(user_id)
+    return __get_request(**request_info)
+
+
+@data_request(transformer=no_transform)
+def create_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
+    """
+    Create offline token for user.
+
+    Args:
+        user_id (str): User ID
+        refresh_token (str): Refresh token
+        exp: (Optional[Int]): Expiration timestamp
+
+    Returns:
+        dict: Offline token response
+    """
+    request_info = _create_offline_token_request_info(user_id, refresh_token, exp)
+    return __put_request(**request_info)
+
+
+@data_request(transformer=no_transform)
+def update_offline_token(user_id: str, refresh_token: str, exp: Optional[int] = None) -> dict:
+    """
+    Update offline token for user.
+
+    Args:
+        user_id (str): User ID
+        refresh_token (str): Refresh token
+        exp: (Optional[Int]): Expiration timestamp
+
+    Returns:
+        dict: Offline token response
+    """
+    request_info = _update_offline_token_request_info(user_id, refresh_token, exp)
+    return __post_request(**request_info)
+
+
+@data_request(transformer=no_transform)
+def delete_offline_token(user_id: str) -> None:
+    """
+    Delete offline token for user.
+
+    Args:
+        user_id (str): User ID
+
+    Returns:
+        None
+    """
+    request_info = _delete_offline_token_request_info(user_id)
+    return __delete_request(**request_info)
