@@ -1,5 +1,5 @@
 from datetime import date
-from typing import Optional
+from typing import Optional, Dict, Any
 
 from algora.api.service.backtest.state.enum import BacktestEventType
 from algora.common.base import Base
@@ -24,7 +24,7 @@ class PortfolioStateRequest(Base):
     date: date
     valuation: float
     pnl: float
-    portfolio: str
+    portfolio: Dict[str, Any]
 
 
 class CashPaymentResponse(BacktestEvent):
@@ -46,7 +46,7 @@ class PortfolioStateResponse(BacktestEvent):
     date: date
     valuation: float
     pnl: float
-    portfolio: str
+    portfolio: Dict[str, Any]
     created_at: int
 
 
