@@ -1,4 +1,4 @@
 def _get_or_create_runner_request_info() -> dict:
     return {
-        'endpoint': f"research-service/runner/deployment"
+        'endpoint': f"job/runner/deployment"
     }
